<?php
/**
 * Bulk Mail Send
 *
 * @package    Bulk Mail Send
 * @subpackage BulkMailSend Main function
/*  Copyright (c) 2020- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

$bulkmailsend = new BulkMailSend();

/** ==================================================
 * Class Main function
 *
 * @since 1.00
 */
class BulkMailSend {

	/** ==================================================
	 * Construct
	 *
	 * @since 1.00
	 */
	public function __construct() {

		add_action( 'bms_user_search_form', array( $this, 'user_search_form' ) );
		add_action( 'bms_user_role_select_form', array( $this, 'role_select_form' ) );
		add_action( 'bms_order_search_form', array( $this, 'order_search_form' ) );
		add_action( 'bms_order_product_select_form', array( $this, 'product_select_form' ) );

	}

	/** ==================================================
	 * Users search form
	 *
	 * @since 1.00
	 */
	public function user_search_form() {

		$search_text = get_user_option( 'bulkmailsenduser_search_text', get_current_user_id() );

		?>
		<div style="margin: 0px; text-align: right;">
		<form method="post">
		<?php
		wp_nonce_field( 'bmsu_search_text', 'bulk_media_send_user_search_text' );
		if ( empty( $search_text ) ) {
			?>
			<input name="search_text" type="text" value="" placeholder="<?php echo esc_attr__( 'Search' ); ?>">
			<?php
		} else {
			?>
			<input name="search_text" type="text" value="" placeholder="<?php echo esc_attr( $search_text ); ?>">
			<?php
		}
		submit_button( __( 'Search' ), 'large', 'bulk-mail-send-user-searchtext', false );
		?>
		</form>
		</div>
		<?php

	}

	/** ==================================================
	 * Orders search form
	 *
	 * @since 1.00
	 */
	public function order_search_form() {

		$search_text = get_user_option( 'bulkmailsendorder_search_text', get_current_user_id() );

		?>
		<div style="margin: 0px; text-align: right;">
		<form method="post">
		<?php
		wp_nonce_field( 'bmso_search_text', 'bulk_media_send_order_search_text' );
		if ( empty( $search_text ) ) {
			?>
			<input name="search_text" type="text" value="" placeholder="<?php echo esc_attr__( 'Search' ); ?>">
			<?php
		} else {
			?>
			<input name="search_text" type="text" value="" placeholder="<?php echo esc_attr( $search_text ); ?>">
			<?php
		}
		submit_button( __( 'Search' ), 'large', 'bulk-mail-send-order-searchtext', false );
		?>
		</form>
		</div>
		<?php

	}

	/** ==================================================
	 * Role select form
	 *
	 * @since 1.00
	 */
	public function role_select_form() {

		$search_text = get_user_option( 'bulkmailsenduser_search_text', get_current_user_id() );

		global $wp_roles;
		$all_roles = $wp_roles->roles;

		?>
		<form method="post">
		<?php wp_nonce_field( 'bmsu_role_text', 'bulk_media_send_user_role_text' ); ?>
		<div>
		<select name="role">
		<?php
		$select = false;
		foreach ( $all_roles as $key => $value ) {
			if ( $key === $search_text ) {
				$select = true;
				?>
				<option value="<?php echo esc_attr( $key ); ?>" selected><?php echo esc_html( $value['name'] ); ?></option>
				<?php
			} else {
				?>
				<option value="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $value['name'] ); ?></option>
				<?php
			}
		}
		if ( $select ) {
			?>
			<option value=""><?php esc_html_e( 'All roles', 'bulk-mail-send' ); ?></option>
			<?php
		} else {
			?>
			<option value="" selected><?php esc_html_e( 'All roles', 'bulk-mail-send' ); ?></option>
			<?php
		}
		?>
		</select>
		<?php submit_button( __( 'Search' ), 'large', 'bulk-mail-send-user-roletext', false ); ?>
		</div>
		</form>
		<?php

	}

	/** ==================================================
	 * Product select form
	 *
	 * @since 1.00
	 */
	public function product_select_form() {

		$search_text = get_user_option( 'bulkmailsendorder_search_text', get_current_user_id() );

		global $wpdb;

		$all_products = $wpdb->get_col(
			"
			SELECT post_title
			FROM {$wpdb->prefix}posts
			WHERE post_type = 'product'
			"
		);

		?>
		<form method="post">
		<?php wp_nonce_field( 'bmso_product_text', 'bulk_media_send_order_product_text' ); ?>
		<div>
		<select name="product">
		<?php
		$select = false;
		foreach ( $all_products as $product ) {
			if ( $product === $search_text ) {
				$select = true;
				?>
				<option value="<?php echo esc_attr( $product ); ?>" selected><?php echo esc_html( $product ); ?></option>
				<?php
			} else {
				?>
				<option value="<?php echo esc_attr( $product ); ?>"><?php echo esc_html( $product ); ?></option>
				<?php
			}
		}
		if ( $select ) {
			?>
			<option value=""><?php esc_html_e( 'All products', 'woocommerce' ); ?></option>
			<?php
		} else {
			?>
			<option value="" selected><?php esc_html_e( 'All products', 'woocommerce' ); ?></option>
			<?php
		}
		?>
		</select>
		<?php submit_button( __( 'Search' ), 'large', 'bulk-mail-send-order-producttext', false ); ?>
		</div>
		</form>
		<?php

	}

}


